==> adms-2.2.4.tar.gz: adms-2.2.4/admsObject/objectSource.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectsource_h
#define objectsource_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_source_enumeration_dynamic_no,
  adms_source_enumeration_dynamic_yes
} e_source_dynamic;
win32_interface char* adms_source_tostring_dynamic_impl (p_admsttransform myadmsttransform,e_source_dynamic e);
win32_interface e_source_dynamic adms_source_fromstring_dynamic_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_whitenoise_no,
  adms_source_enumeration_whitenoise_yes
} e_source_whitenoise;
win32_interface char* adms_source_tostring_whitenoise_impl (p_admsttransform myadmsttransform,e_source_whitenoise e);
win32_interface e_source_whitenoise adms_source_fromstring_whitenoise_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_flickernoise_no,
  adms_source_enumeration_flickernoise_yes
} e_source_flickernoise;
win32_interface char* adms_source_tostring_flickernoise_impl (p_admsttransform myadmsttransform,e_source_flickernoise e);
win32_interface e_source_flickernoise adms_source_fromstring_flickernoise_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_grounded_no,
  adms_source_enumeration_grounded_yes
} e_source_grounded;
win32_interface char* adms_source_tostring_grounded_impl (p_admsttransform myadmsttransform,e_source_grounded e);
win32_interface e_source_grounded adms_source_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_static_no,
  adms_source_enumeration_static_yes
} e_source_static;
win32_interface char* adms_source_tostring_static_impl (p_admsttransform myadmsttransform,e_source_static e);
win32_interface e_source_static adms_source_fromstring_static_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_type_flicker,
  adms_source_enumeration_type_fs,
  adms_source_enumeration_type_ps,
  adms_source_enumeration_type_shot,
  adms_source_enumeration_type_thermal
} e_source_type;
win32_interface char* adms_source_tostring_type_impl (p_admsttransform myadmsttransform,e_source_type e);
win32_interface e_source_type adms_source_fromstring_type_impl (p_admsttransform myadmsttransform,char*token);
struct s_source {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
  p_nature _nature;
  int _nature_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  e_source_dynamic _dynamic;
  int _dynamic_isdefault : 1;
  e_source_whitenoise _whitenoise;
  int _whitenoise_isdefault : 1;
  e_source_flickernoise _flickernoise;
  int _flickernoise_isdefault : 1;
  e_source_grounded _grounded;
  int _grounded_isdefault : 1;
  e_source_static _static;
  int _static_isdefault : 1;
  e_source_type _type;
  int _type_isdefault : 1;
  GSList* _probe;
  int _probe_isdefault : 1;
  GSList* _attribute;
  int _attribute_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectAttribute.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_source_getuid (p_source mysource);
win32_interface gboolean adms_source_cmp (p_source mysource,p_source refsource);
win32_interface p_source adms_source_new_1 (p_module mymodule,p_branch mybranch,p_nature mynature);
#define adms_source_free_debug(item)\
  adms_adms(item)->_freed=adms_adms_enumeration_freed_yes;
#define adms_source_free(item)\
{\
  free(item);\
}
win32_interface p_adms adms_source_new_impl (p_adms arguments[]);
win32_interface p_source adms_source_impl (void* member);
#define adms_source(member) ((p_source) (member))
#define adms_source_new adms_source_new_1
#define adms_source_isdefault_module(source) (adms_source(source)->_module_isdefault)
#define adms_source_valueof_module(source) (adms_source(source)->_module)
#define adms_source_isdefault_branch(source) (adms_source(source)->_branch_isdefault)
#define adms_source_valueof_branch(source) (adms_source(source)->_branch)
#define adms_source_isdefault_nature(source) (adms_source(source)->_nature_isdefault)
#define adms_source_valueof_nature(source) (adms_source(source)->_nature)
#define adms_source_isdefault_discipline(source) (adms_source(source)->_discipline_isdefault)
#define adms_source_valueof_discipline(source) (adms_source(source)->_discipline)
#define adms_source_isdefault_dynamic(source) (adms_source(source)->_dynamic_isdefault)
#define adms_source_valueof_dynamic(source) (adms_source(source)->_dynamic)
#define adms_source_isdefault_whitenoise(source) (adms_source(source)->_whitenoise_isdefault)
#define adms_source_valueof_whitenoise(source) (adms_source(source)->_whitenoise)
#define adms_source_isdefault_flickernoise(source) (adms_source(source)->_flickernoise_isdefault)
#define adms_source_valueof_flickernoise(source) (adms_source(source)->_flickernoise)
#define adms_source_isdefault_grounded(source) (adms_source(source)->_grounded_isdefault)
#define adms_source_valueof_grounded(source) (adms_source(source)->_grounded)
#define adms_source_isdefault_static(source) (adms_source(source)->_static_isdefault)
#define adms_source_valueof_static(source) (adms_source(source)->_static)
#define adms_source_isdefault_type(source) (adms_source(source)->_type_isdefault)
#define adms_source_valueof_type(source) (adms_source(source)->_type)
#define adms_source_isdefault_probe(source) (adms_source(source)->_probe_isdefault)
#define adms_source_valueof_probe(source) (adms_source(source)->_probe)
#define adms_source_isdefault_attribute(source) (adms_source(source)->_attribute_isdefault)
#define adms_source_valueof_attribute(source) (adms_source(source)->_attribute)
#define adms_source_valueof_adms(source) ((p_adms)source)
#define adms_source_valueto_module(a,b) ((p_source)a)->_module=(b)
win32_interface void adms_source_valueto_module_impl (p_source mysource,p_module _module);
#define adms_source_valueto_branch(a,b) ((p_source)a)->_branch=(b)
win32_interface void adms_source_valueto_branch_impl (p_source mysource,p_branch _branch);
#define adms_source_valueto_nature(a,b) ((p_source)a)->_nature=(b)
win32_interface void adms_source_valueto_nature_impl (p_source mysource,p_nature _nature);
#define adms_source_valueto_discipline(a,b) ((p_source)a)->_discipline=(b)
win32_interface void adms_source_valueto_discipline_impl (p_source mysource,p_discipline _discipline);
#define adms_source_valueto_dynamic(a,b) ((p_source)a)->_dynamic=(b)
win32_interface void adms_source_valueto_dynamic_impl (p_source mysource,e_source_dynamic _dynamic);
#define adms_source_valueto_whitenoise(a,b) ((p_source)a)->_whitenoise=(b)
win32_interface void adms_source_valueto_whitenoise_impl (p_source mysource,e_source_whitenoise _whitenoise);
#define adms_source_valueto_flickernoise(a,b) ((p_source)a)->_flickernoise=(b)
win32_interface void adms_source_valueto_flickernoise_impl (p_source mysource,e_source_flickernoise _flickernoise);
#define adms_source_valueto_grounded(a,b) ((p_source)a)->_grounded=(b)
win32_interface void adms_source_valueto_grounded_impl (p_source mysource,e_source_grounded _grounded);
#define adms_source_valueto_static(a,b) ((p_source)a)->_static=(b)
win32_interface void adms_source_valueto_static_impl (p_source mysource,e_source_static _static);
#define adms_source_valueto_type(a,b) ((p_source)a)->_type=(b)
win32_interface void adms_source_valueto_type_impl (p_source mysource,e_source_type _type);
#define adms_source_valueto_probe(a,b) ((p_source)a)->_probe=(b)
win32_interface void adms_source_valueto_probe_impl (p_source mysource,GSList* _probe);
win32_interface p_probe adms_source_list_probe_lookup_by_id (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_source_list_probe_prepend_by_id (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_source_list_probe_prepend_by_id_once_or_ignore (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface void adms_source_list_probe_prepend_once_or_ignore (p_source mymysource,p_probe myprobe);
#define adms_source_valueto_attribute(a,b) ((p_source)a)->_attribute=(b)
win32_interface void adms_source_valueto_attribute_impl (p_source mysource,GSList* _attribute);
win32_interface p_attribute adms_source_list_attribute_lookup_by_id (p_source mymysource,char* myname);
win32_interface p_attribute adms_source_list_attribute_prepend_by_id (p_source mymysource,char* myname);
win32_interface p_attribute adms_source_list_attribute_prepend_by_id_once_or_ignore (p_source mymysource,char* myname);
win32_interface void adms_source_list_attribute_prepend_once_or_ignore (p_source mymysource,p_attribute myattribute);
#endif /* objectsource_h */

==> adms-2.2.5.tar.gz: adms-2.2.5/admsObject/objectSource.h <==

/* ------- code automatically created by ../scripts/adms_build_object.pl -------------- */

#ifndef objectsource_h
#define objectsource_h
#include <admsObject/admsH.h>
#include <admsObject/objectAdms.h>
typedef enum {
  adms_source_enumeration_static_no,
  adms_source_enumeration_static_yes
} e_source_static;
win32_interface char* adms_source_tostring_static_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_static adms_source_fromstring_static_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_dynamic_no,
  adms_source_enumeration_dynamic_yes
} e_source_dynamic;
win32_interface char* adms_source_tostring_dynamic_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_dynamic adms_source_fromstring_dynamic_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_whitenoise_no,
  adms_source_enumeration_whitenoise_yes
} e_source_whitenoise;
win32_interface char* adms_source_tostring_whitenoise_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_whitenoise adms_source_fromstring_whitenoise_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_flickernoise_no,
  adms_source_enumeration_flickernoise_yes
} e_source_flickernoise;
win32_interface char* adms_source_tostring_flickernoise_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_flickernoise adms_source_fromstring_flickernoise_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_grounded_no,
  adms_source_enumeration_grounded_yes
} e_source_grounded;
win32_interface char* adms_source_tostring_grounded_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_grounded adms_source_fromstring_grounded_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_switch_no,
  adms_source_enumeration_switch_yes
} e_source_switch;
win32_interface char* adms_source_tostring_switch_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_switch adms_source_fromstring_switch_impl (p_admsttransform myadmsttransform,char*token);
typedef enum {
  adms_source_enumeration_type_flicker,
  adms_source_enumeration_type_fs,
  adms_source_enumeration_type_ps,
  adms_source_enumeration_type_shot,
  adms_source_enumeration_type_thermal
} e_source_type;
win32_interface char* adms_source_tostring_type_impl (p_admsttransform myadmsttransform,p_enumeration myenumeration);
win32_interface e_source_type adms_source_fromstring_type_impl (p_admsttransform myadmsttransform,char*token);
struct s_source {
  t_adms _adms;
  p_module _module;
  int _module_isdefault : 1;
  p_branch _branch;
  int _branch_isdefault : 1;
  p_nature _nature;
  int _nature_isdefault : 1;
  p_discipline _discipline;
  int _discipline_isdefault : 1;
  p_enumeration _static;
  int _static_isdefault : 1;
  p_enumeration _dynamic;
  int _dynamic_isdefault : 1;
  p_enumeration _whitenoise;
  int _whitenoise_isdefault : 1;
  p_enumeration _flickernoise;
  int _flickernoise_isdefault : 1;
  p_enumeration _grounded;
  int _grounded_isdefault : 1;
  p_enumeration _switch;
  int _switch_isdefault : 1;
  p_enumeration _type;
  int _type_isdefault : 1;
  p_slist _probe;
  int _probe_isdefault : 1;
  p_slist _attribute;
  int _attribute_isdefault : 1;
};
#include <admsObject/objectModule.h>
#include <admsObject/objectBranch.h>
#include <admsObject/objectNature.h>
#include <admsObject/objectDiscipline.h>
#include <admsObject/objectEnumeration.h>
#include <admsObject/objectProbe.h>
#include <admsObject/objectAttribute.h>

#undef win32_interface
#if defined(WIN32)
#  if defined(_inside_admsObject)
#    define win32_interface __declspec(dllexport)
#  else
#    define win32_interface __declspec(dllimport)
#  endif
#else
#  define win32_interface extern
#endif

win32_interface char*adms_source_uid (p_source mysource);
win32_interface int adms_source_cmp (p_source mysource,p_source refsource);
win32_interface p_source adms_source_new(p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_adms adms_source_new_impl (p_adms arguments[]);
#define adms_source(member) ((p_source) (member))
#define adms_source_isdefault_module(source) (adms_source(source)->_module_isdefault)
#define adms_source_valueof_module(source) (adms_source(source)->_module)
#define adms_source_isdefault_branch(source) (adms_source(source)->_branch_isdefault)
#define adms_source_valueof_branch(source) (adms_source(source)->_branch)
#define adms_source_isdefault_nature(source) (adms_source(source)->_nature_isdefault)
#define adms_source_valueof_nature(source) (adms_source(source)->_nature)
#define adms_source_isdefault_discipline(source) (adms_source(source)->_discipline_isdefault)
#define adms_source_valueof_discipline(source) (adms_source(source)->_discipline)
#define adms_source_isdefault_static(source) (adms_source(source)->_static_isdefault)
#define adms_source_valueof_static(source) (adms_source(source)->_static)
#define adms_source_isdefault_dynamic(source) (adms_source(source)->_dynamic_isdefault)
#define adms_source_valueof_dynamic(source) (adms_source(source)->_dynamic)
#define adms_source_isdefault_whitenoise(source) (adms_source(source)->_whitenoise_isdefault)
#define adms_source_valueof_whitenoise(source) (adms_source(source)->_whitenoise)
#define adms_source_isdefault_flickernoise(source) (adms_source(source)->_flickernoise_isdefault)
#define adms_source_valueof_flickernoise(source) (adms_source(source)->_flickernoise)
#define adms_source_isdefault_grounded(source) (adms_source(source)->_grounded_isdefault)
#define adms_source_valueof_grounded(source) (adms_source(source)->_grounded)
#define adms_source_isdefault_switch(source) (adms_source(source)->_switch_isdefault)
#define adms_source_valueof_switch(source) (adms_source(source)->_switch)
#define adms_source_isdefault_type(source) (adms_source(source)->_type_isdefault)
#define adms_source_valueof_type(source) (adms_source(source)->_type)
#define adms_source_isdefault_probe(source) (adms_source(source)->_probe_isdefault)
#define adms_source_valueof_probe(source) (adms_source(source)->_probe)
#define adms_source_isdefault_attribute(source) (adms_source(source)->_attribute_isdefault)
#define adms_source_valueof_attribute(source) (adms_source(source)->_attribute)
#define adms_source_valueof_adms(source) ((p_adms)source)
win32_interface inline void adms_source_valueto_module (p_source mysource,p_module _module);
win32_interface inline void adms_source_valueto_branch (p_source mysource,p_branch _branch);
win32_interface inline void adms_source_valueto_nature (p_source mysource,p_nature _nature);
win32_interface inline void adms_source_valueto_discipline (p_source mysource,p_discipline _discipline);
win32_interface inline void adms_source_valueto_static (p_source mysource,p_enumeration _static);
win32_interface inline void adms_source_valueto_dynamic (p_source mysource,p_enumeration _dynamic);
win32_interface inline void adms_source_valueto_whitenoise (p_source mysource,p_enumeration _whitenoise);
win32_interface inline void adms_source_valueto_flickernoise (p_source mysource,p_enumeration _flickernoise);
win32_interface inline void adms_source_valueto_grounded (p_source mysource,p_enumeration _grounded);
win32_interface inline void adms_source_valueto_switch (p_source mysource,p_enumeration _switch);
win32_interface inline void adms_source_valueto_type (p_source mysource,p_enumeration _type);
win32_interface inline void adms_source_valueto_probe (p_source mysource,p_slist _probe);
win32_interface p_probe adms_source_list_probe_lookup_by_id (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_source_list_probe_prepend_by_id (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface p_probe adms_source_list_probe_prepend_by_id_once_or_ignore (p_source mymysource,p_module mymodule,p_branch mybranch,p_nature mynature);
win32_interface void adms_source_list_probe_prepend_once_or_ignore (p_source mymysource,p_probe myprobe);
win32_interface inline void adms_source_valueto_attribute (p_source mysource,p_slist _attribute);
win32_interface p_attribute adms_source_list_attribute_lookup_by_id (p_source mymysource,p_quark myname);
win32_interface p_attribute adms_source_list_attribute_prepend_by_id (p_source mymysource,p_quark myname);
win32_interface p_attribute adms_source_list_attribute_prepend_by_id_once_or_ignore (p_source mymysource,p_quark myname);
win32_interface void adms_source_list_attribute_prepend (p_source mymysource,p_attribute myattribute);
win32_interface inline void adms_source_free(p_source mysource);
#endif /* objectsource_h */
